Documentation
¶
Overview ¶
Goptuna integration for d4l3k/go-bayesopt, the library for Gaussian Process based Bayesian Optimization.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Sampler ¶
type Sampler struct {
// contains filtered or unexported fields
}
Sampler for Gaussian Process based Bayesian Optimization.
func NewSampler ¶
func NewSampler(opts ...SamplerOption) *Sampler
Sampler returns the next search points
type SamplerOption ¶
type SamplerOption func(sampler *Sampler)
SamplerOption is a type of function to set change the option.
func SamplerOptionOptimizerOptions ¶
func SamplerOptionOptimizerOptions(opts []bo.OptimizerOption) SamplerOption
SamplerOptionOptimizerOptions sets options for d4l3k/go-bayesopt's optimizer.
func SamplerOptionSeed ¶
func SamplerOptionSeed(seed int64) SamplerOption
SamplerOptionSeed sets seed number.
Click to show internal directories.
Click to hide internal directories.